@@ -2,9 +2,8 @@ package Crypt::Random::Source;
 BEGIN {
   $Crypt::Random::Source::AUTHORITY = 'cpan:NUFFIN';
 }
-BEGIN {
-  $Crypt::Random::Source::VERSION = '0.07';
-}
+# git description: v0.07-12-g69cb5f2
+$Crypt::Random::Source::VERSION = '0.08';
 # ABSTRACT: Get weak or strong random data from pluggable sources
 
 use strict;
@@ -40,18 +39,18 @@ END { undef $weak; undef $strong; undef $any; undef $factory }
 
 1;
 
-
-# ex: set sw=4 et:
-
-__END__
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Crypt::Random::Source - Get weak or strong random data from pluggable sources
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
     use Crypt::Random::Source qw(get_strong);
@@ -88,14 +87,44 @@ L<Crypt::Random>, L<Crypt::Util>
 
 =head1 AUTHOR
 
-  Yuval Kogman <nothingmuch@woobling.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yuval Kogman.
+This software is copyright (c) 2008 by Yuval Kogman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+David Pottage <spudsoup@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Max Kanat-Alexander <mkanat@es-compy.(none)>
+
+=item *
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=back
+
 =cut
 
+__END__
+
+
+# ex: set sw=4 et
