@@ -2,11 +2,8 @@ package Crypt::Random::Source::Base::RandomDevice;
 BEGIN {
   $Crypt::Random::Source::Base::RandomDevice::AUTHORITY = 'cpan:NUFFIN';
 }
-BEGIN {
-  $Crypt::Random::Source::Base::RandomDevice::VERSION = '0.07';
-}
 # ABSTRACT: Base class for random devices
-
+$Crypt::Random::Source::Base::RandomDevice::VERSION = '0.08';
 use Any::Moose;
 
 extends qw(Crypt::Random::Source::Base::File);
@@ -37,18 +34,18 @@ sub default_path {
 
 1;
 
-
-# ex: set sw=4 et:
-
-__END__
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Crypt::Random::Source::Base::RandomDevice - Base class for random devices
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
     use Moose;
@@ -66,14 +63,18 @@ L<Crypt::Random::Source::Weak::devurandom> for actual implementations.
 
 =head1 AUTHOR
 
-  Yuval Kogman <nothingmuch@woobling.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yuval Kogman.
+This software is copyright (c) 2008 by Yuval Kogman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+__END__
+
+
+# ex: set sw=4 et:
